@@ -1,6 +1,6 @@
 package Map::Tube::London;
 
-$Map::Tube::London::VERSION = '0.18';
+$Map::Tube::London::VERSION = '0.19';
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Map::Tube::London - Interface to the London Tube Map.
 
 =head1 VERSION
 
-Version 0.18
+Version 0.19
 
 =cut
 
@@ -26,9 +26,37 @@ with 'Map::Tube';
 =head1 DESCRIPTION
 
 It currently provides functionality to find the shortest  route between  the  two
-given  nodes. It  covers  Bakerloo, Central, Circle, District, DLR, Hammersmith &
-City,  Jubilee,  Metropolitan,  Northern,  Overground,  Piccadilly,  Victoria and
-Waterloo & City.
+given nodes. It covers the following tube lines:
+
+=over 2
+
+=item * L<Bakerloo Line|Map::Tube::London::Line::Barkerloo>
+
+=item * L<Central Line|Map::Tube::London::Line::Central>
+
+=item * Circle Line
+
+=item * District Line
+
+=item * Dockland Light Railway Line
+
+=item * Hammersmith & City Line
+
+=item * Jubilee Line
+
+=item * Metropolitan Line
+
+=item * Northern Line
+
+=item * London Overground Line
+
+=item * Piccadilly Line
+
+=item * Victoria Line
+
+=item * Waterloo & City Line
+
+=back
 
 =head1 CONSTRUCTOR
 
